.. SPDX-FileCopyrightText: Copyright © 2024 Idiap Research Institute <contact@idiap.ch>
..
.. SPDX-License-Identifier: GPL-3.0-or-later

.. _mednet.databases.segment.iostar:

========
 IOSTAR
========

* DataModule and support code: :py:mod:`.data.segment.iostar`
* Splits:

  .. list-table::
     :align: left

     * - Config. key
       - Module
     * - ``iostar-vessel``
       - :py:mod:`.config.segment.data.iostar.vessel`
     * - ``iostar-disc``
       - :py:mod:`.config.segment.data.iostar.optic_disc`
